<?php

/**
 * Shortcodes
 * See the documentation or look in this file for information on how to use them
 */
 
// Add the shortcodes
add_shortcode( 'email', 'fap_email_func' );
add_shortcode( 'private', 'fap_private_content' );
add_shortcode( 'map', 'fap_googlemaps' );
add_shortcode( 'visitor', 'fap_visitor_check' );
add_shortcode( 'member', 'fap_member_check' );
add_shortcode( 'pdf', 'fap_pdf' );
add_shortcode( 'highlight', 'fap_highlight' );
add_shortcode( 'hr', 'fap_hr' );
add_shortcode( 'year', 'fap_year');
add_shortcode( 'site-link', 'fap_site_link' );
add_shortcode( 'site-name', 'fap_site_name' );
add_shortcode( 'wp-link', 'fap_wp_link' );
add_shortcode( 'theme-link', 'fap_theme_link' );
add_shortcode( 'loginout-link', 'fap_loginout' );
add_shortcode( 'success', 'fap_success_shortcode' );
add_shortcode( 'download', 'fap_download_shortcode' );
add_shortcode( 'error', 'fap_error_shortcode' );
add_shortcode( 'warning', 'fap_warning_shortcode' );
add_shortcode( 'tip', 'fap_tip_shortcode' );
add_shortcode( 'box', 'fap_box_shortcode' );
add_shortcode( 'btn', 'fap_btn_shortcode' );

add_filter( 'widget_text', 'do_shortcode' );  // Use shortcodes in text widgets
// add_filter( 'comment_text', 'do_shortcode' ); // Uncomment if you want shortcodes in comments
 
/**
 * Converts email addresses characters to HTML entities to block spam bots.
 * Usage: [email]email@example.com[/email]
 * Produces something like this in the HTML: &#100;in&#101;m&#97;i&#108;&#64;&#100;i&#110;&#115;&#105;de.&#100;&#107;
 */
function fap_email_func( $atts, $content = null ) {
	return antispambot( $content ); 
}
 
/**
 * Add private content that only Administrators, Editor and Authors can see
 * Usage: [private] content [/private]
 */
function fap_private_content( $atts, $content = null ) {
	if ( current_user_can( 'publish_posts' ) )
		return '<div class="private-content">' . do_shortcode( $content ) . '</div>';
	return '';
}

/**
 * Google Maps Shortcode
 * Usage: [map width="610" height="350" src=" url "]
 * Credits: http://digwp.com/2010/01/google-maps-shortcode
 */
function fap_googlemaps( $atts, $content = null ) {
   extract( shortcode_atts( array(
      "width" => '610',
      "height" => '350',
      "src" => ''
   ), $atts) );
   
	if ( $src )
		return '<iframe class="googlemap" width="' . intval( $width ) . '" height="' . intval( $height ) . '" src="' . esc_url ( $src ) . '"></iframe>'; 
}

/**
 * Content for users that are NOT logged in
 * Usage: [visitor] content [/visitor]
 * Credits: http://justintadlock.com/archives/2009/05/09/using-shortcodes-to-show-members-only-content
 */
function fap_visitor_check( $atts, $content = null ) {
	 if ( ( !is_user_logged_in() && !is_null( $content ) ) || is_feed() )
		return do_shortcode( $content );
	return '';
}

/**
 * Showing content to logged-in users´
 * Usage: [member] content [/member]
 * Credits: http://justintadlock.com/archives/2009/05/09/using-shortcodes-to-show-members-only-content
 */
function fap_member_check( $atts, $content = null ) {
	 if ( is_user_logged_in() && !is_null( $content ) && !is_feed() )
		return do_shortcode( $content );
	return '';
}

/**
 * PDF viewer through Google Docs
 * Usage: [pdf href="linktoyour.pdf"]View PDF[/pdf]
 * Credits: http://noscope.com/journal/2010/02/wordpress-trick-create-a-google-viewer-pdf-shortcode
 */
function fap_pdf( $attr, $content ) {
	return '<a href="http://docs.google.com/viewer?url=' . esc_url( $attr['href'] ) . '" class="pdf">' . $content . '</a>';
}

/**
 * Highlight word
 * Usage: [highlight]Word to highlight[/highlight]
 */
function fap_highlight( $attr, $content ) {
	return '<span class="highlight">' . do_shortcode( $content ) . '</span>';
}

/**
 * Creates a horizontal line
 * Usage: [hr]
 */
function fap_hr() {
	return '<hr />';
}

/**
 * Returns the current year
 * Usage: [year]
 * Credits to Hybrid for this and the next couple of shortcodes
 */
function fap_year() {   
    return date( 'Y' );
}

/**
 * Display a link back to the site
 * Usage: [site-link]
 */
function fap_site_link() {
	return '<a class="site-link" href="' . home_url() . '" title="' . get_bloginfo( 'name' ) . '" rel="home">' . get_bloginfo( 'name' ) . '</a>';
}

/**
 * Shortcode to display the name of the site
 * Usage: [site-name]
 */
function fap_site_name() {
	return get_bloginfo( 'name' );
}

/**
 * Display a link to WordPress.org
 * Usage: [wp-link]
 */
function fap_wp_link() {
	return '<a class="wp-link" href="http://wordpress.org" title="' . esc_attr__( 'Powered by WordPress, state-of-the-art semantic personal publishing platform', 'fap' ) . '">WordPress</a>';
}

/**
 * Display a link to the theme page 
 * Usage: [theme-link]
 */
function fap_theme_link() {
	$data = get_theme_data( TEMPLATEPATH . '/style.css' );
	return '<a class="theme-link" href="' . esc_url( $data['URI'] ) . '" title="' . esc_attr( $data['Name'] ) . '">' . esc_attr( $data['Name'] ) . '</a>';
}

/**
 * Display a login/logout link 
 * Usage: [loginout-link]
 */
function fap_loginout() {
	return wp_loginout( esc_url( $_SERVER['HTTP_REFERER'] ), false );
}

/**
 * Message shortcodes
 * [success], [error], [warning], [tip}, [box]
 * Example usage: [success]Great![/success]
 */
function fap_success_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'icon' => ''
	), $atts) );
	
	$noicon = ( $icon != "" ) ? 'noicon' : ''; 
	return '<p class="success ' . $noicon . '">' . do_shortcode( $content ) . '</p>';
}

function fap_download_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'icon' => ''
	), $atts) );
	
	$noicon = ( $icon != "" ) ? 'noicon' : ''; 
	return '<p class="download ' . $noicon . '">' . do_shortcode( $content ) . '</p>';
}

function fap_error_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'icon' => ''
	), $atts) );
	
	$noicon = ( $icon != "" ) ? 'noicon' : ''; 
	return '<p class="error ' . $noicon . '">' . do_shortcode( $content ) . '</p>';
}

function fap_warning_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'icon' => ''
	), $atts) );
	
	$noicon = ( $icon != "" ) ? 'noicon' : ''; 
	return '<p class="warning ' . $noicon . '">' . do_shortcode( $content ) . '</p>';
}

function fap_tip_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'icon' => ''
	), $atts) );
	
	$noicon = ( $icon != "" ) ? 'noicon' : ''; 
	return '<p class="tip ' . $noicon . '">' . do_shortcode( $content ) . '</p>';
}

function fap_box_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'icon' => ''
	), $atts) );
	
	$noicon = ( $icon != "" ) ? 'noicon' : ''; 
	return '<p class="box ' . $noicon . '">' . do_shortcode( $content ) . '</p>';
}

/**
 * Button shortcode
 */
function fap_btn_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'href' => '',
		'color' => '',
		'size' => '',
		'glow' => ''
	), $atts) );
	
	$gloww = ( $glow ) ? ' glow' . $glow : '';
	
	return '<a href="' . esc_url( $href ) . '" class="btn ' . $color . $size . $gloww . '">' . $content . '</a>';
}

/**
 * Layout shortcodes
 * Example usage: [one_half]Content[/one_half] [one_half_last]More content[/one_half_last]
 */
function fap_one_half( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="one-half">' . do_shortcode( $content ) . '</div>';
}

function fap_one_half_last( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="one-half last">' . do_shortcode( $content ) . '</div> <div class="clear"></div>';
}

function fap_one_third( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="one-third">' . do_shortcode( $content ) . '</div>';
}

function fap_one_third_last( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="one-third last">' . do_shortcode( $content ) . '</div> <div class="clear"></div>';
}

function fap_two_third( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="two-third">' . do_shortcode( $content ) . '</div>';
}

function fap_one_fourth( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="one-fourth">' . do_shortcode( $content ) . '</div>';
}

function fap_one_fourth_last( $atts, $content = null ) {
	$content = preg_replace('#^<\/p>|<p>$#', '', $content);
    return '<div class="one-fourth last">' . do_shortcode( $content ) . '</div> <div class="clear"></div>';
}

add_shortcode( 'one_half', 'fap_one_half' );
add_shortcode( 'one_half_last', 'fap_one_half_last' );
add_shortcode( 'one_third', 'fap_one_third' );
add_shortcode( 'one_third_last', 'fap_one_third_last' );
add_shortcode( 'two_third', 'fap_two_third' );
add_shortcode( 'one_fourth', 'fap_one_fourth' );
add_shortcode( 'one_fourth_last', 'fap_one_fourth_last' );

?>