<?php

/**
 * Add some new widgets 
 * Post meta, Author box, Social icons, Twitter, Flickr, Popular posts and Author list
 */


// Register our widgets
function fap_load_widgets() {
	register_widget( 'Fap_postmeta' );
	register_widget( 'Fap_authorbox' );
	register_widget( 'Fap_social' );
	register_widget( 'Fap_twitter' );
	register_widget( 'Fap_flickr' );
	register_widget( 'Fap_popular' );
	register_widget( 'Fap_authors' );
}

add_action( 'widgets_init', 'fap_load_widgets' );

/*
 * Post meta widget for single posts
 */
class Fap_postmeta extends WP_Widget {

	function fap_postmeta() {
		$widget_ops = array( 'classname' => 'entry-utility entry-meta', 'description' => 'This widget is for post meta on single posts.' );

		$this->WP_Widget( 'fap-postmeta',  __('Fap: Post meta', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	 
		extract( $args );
		
		echo $before_widget;

		  $tag_list = get_the_tag_list('', ', ');
		  
		  // If the post has tags
		  if ( $tag_list )
			  $utility_text = __( 'This entry was posted on %1$s in %2$s and tagged %3$s', 'fap' );
		  else 
			  $utility_text = __( 'This entry was posted on %1$s in %2$s', 'fap' );
		  
		  printf(
			  $utility_text,
			  get_the_date(),
			  get_the_category_list( ', ' ),
			  $tag_list
		  );
		  
		  edit_post_link( __( 'Edit' ), ' | <span class="edit-link">', '</span>' );
		
	   echo $after_widget;
   }
	
} // class Fap_postmeta

/*
 * "About the Author" box for single posts
 */
class Fap_authorbox extends WP_Widget {

	function fap_authorbox() {
		$widget_ops = array( 'classname' => 'entry-author-info', 'description' => 'This widget is for a "About the Author" box on single posts.' );

		$this->WP_Widget( 'fap-authorbox',  __('Fap: Author box', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	 
		extract( $args );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$allposts = isset( $instance['show_allposts'] ) ? $instance['show_allposts'] : false;
		
		$name = get_the_author(); 
		
		echo $before_widget;
		
		echo get_avatar( get_the_author_meta( 'user_email' ), 60 );
		echo '<div class="author-description">';
		
		if ( $title )
			echo $before_title . $title . '&nbsp;' . $name . $after_title;

		if ( get_the_author_meta( 'description' ) )
			echo '<p>' . get_the_author_meta( 'description' ) . '</p>';
		else
			echo '<p>' . __('This author has yet to write their bio.', 'fap') . '</p>';
			
		if ( $allposts )		
			echo '<p><a href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '" title="' . sprintf( esc_attr__( 'View all posts by %s', 'fap' ), get_the_author() ) . '">' . __( 'View all posts by', 'fap' ) . ' ' . get_the_author() . ' &rarr;</a></p>';
		
		echo '</div> <!-- end .author-description -->';
		
		echo $after_widget;
		
   }

	// Update the widget settings
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		// Encode HTML for title
		$instance['title'] = esc_html( $new_instance['title'] );
	
		$instance['show_allposts'] = $new_instance['show_allposts'];
		
		return $instance;
	}
	
   function form( $instance ) { 
   
   		$title = $instance['title'];
		$allposts = $instance['show_allposts'];    
		
		$defaults = array( 'title' => __( 'About', 'fap' ), 'show_allposts' => true );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
            <small><?php _e('The author name will be applied after the title', 'fap'); ?></small>
		</p>
        
		<p>
			<input class="checkbox" type="checkbox" <?php if ( $instance['show_allposts'] == true ) echo 'checked="checked'; ?> id="<?php echo $this->get_field_id( 'show_allposts' ); ?>" name="<?php echo $this->get_field_name( 'show_allposts' ); ?>" />
            <label for="<?php echo $this->get_field_id( 'show_allposts' ); ?>"><?php _e('Show link to all posts by the author?', 'fap'); ?></label>
        </p>
        
		<?php
	}
} // class Fap_authorbox


/**
 * Social links for single posts
 */
class Fap_social extends WP_Widget {

	function fap_social() {
		$widget_ops = array( 'classname' => 'social', 'description' => 'Social links for single posts.' );

		$this->WP_Widget( 'fap-social',  __('Fap: Social links', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	 
		extract( $args );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$text = $instance['text'];
		$sites = $instance['sites'];

		$link = get_permalink();
		$posttitle = urlencode( get_the_title() ); // Encode version of the title to make it work on some of the social sites
			
		// Twitter
		if ( in_array('Twitter', $sites) )
			$site .= '<li><a href="http://twitter.com/share" class="twitter-share-button" data-count="vertical">Tweet</a></li><script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>';
			
		if ( in_array('Facebook', $sites) )
			$site .= '<li><a name="fb_share" type="box_count" href="http://www.facebook.com/sharer.php">' . __( 'Share', 'fap' ) . '</a></li><script src="http://static.ak.fbcdn.net/connect.php/js/FB.Share" type="text/javascript"></script>';
		
		// Digg	
		if ( in_array('Digg', $sites) )
			$site .= '<li><a href="http://digg.com/submit?url=' . urlencode( $link ) . '&amp;title=' . $posttitle . '" title="Digg it" rel="nofollow"><img src="' . THEME_URI . '/images/digg.png" alt="Digg" /></a></li>';
		
		// Delicious
		if ( in_array('Delicious', $sites ) )
			$site .= '<li><a href="http://del.icio.us/post?url=' . $link . '&amp;amp;title=' . $posttitle . '" title="Bookmark on Delicious" rel="nofollow"><img src="' . THEME_URI . '/images/delicious.png" alt="" /></a></li>';
		
		// DesignFloat
		if ( in_array('Designfloat', $sites) )
			$site .= '<li><a href="http://www.designfloat.com/submit.php?url=' . $link . '&amp;title=' . $posttitle . '" title="Designfloat" rel="nofollow"><img src="' . THEME_URI . '/images/designfloat.png" alt="Designfloat" /></a></li>';
		
		// Reddit
		if ( in_array('Reddit', $sites) )
			$site .= '<li><a href="http://www.reddit.com/submit?url=' . $link . '&amp;title=' . $posttitle . '" title="Share on Reddit" rel="nofollow"><img src="' . THEME_URI . '/images/reddit.png" alt="Reddit" /></a></li>';
		
		// StumbleUpon
		if ( in_array('StumbleUpon', $sites) )
			$site .= '<li><a href="http://www.stumbleupon.com/submit?url=' . $link . '&amp;amp;title=' . $posttitle .'" title="Share on StumbleUpon" rel="nofollow"><img src="' . THEME_URI . '/images/stumbleupon.png" alt="StumbleUpon" /></a></li>';
		
		echo $before_widget;
		
		if ( $title )
			echo $before_title . $title . $after_title;

		echo '<p class="alignleft">' . htmlspecialchars_decode( $text ) . '</p>';
		
		// Test if some is the most popular social plugins are activated, else use the themes fap_social() function 
		if ( function_exists('selfserv_sexy') )
			selfserv_sexy();
		elseif ( function_exists('sociable_html') )
			echo sociable_html();
		else
			echo "<ul>$site</ul>";
		
		echo $after_widget;
		
   }

	// Update the widget settings
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		// Encode HTML for title
		$instance['title'] = esc_html( $new_instance['title'] );
		$instance['text'] = esc_html( $new_instance['text'] );
		$instance['sites'] = $new_instance['sites'];
		
		return $instance;
	}
	
   function form( $instance ) { 
   
   		$title = $instance['title'];
		$text = $instance['text'];
		$sites = $instance['sites'];    
		
		$defaulttext = sprintf( esc_html__( 'Subscribe to the <a href="%s">RSS feed</a> or share it', 'fap' ), get_bloginfo('rss2_url') );
		
		$socialsites = array( 'Twitter', 'Facebook', 'Digg', 'Delicious', 'Designfloat', 'Reddit', 'StumbleUpon' );
		
		$defaults = array( 'title' => __( 'Enjoy This Post?', 'fap' ), 'text' => $defaulttext, 'sites' => array( 'Twitter', 'Facebook' ) );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'text' ); ?>"><?php _e('Text:'); ?></label>
            <textarea id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" value="" style="height: 80px;" class="widefat"><?php echo $instance['text']; ?></textarea>
        </p>
        
        <p>
        	<label for="<?php echo $this->get_field_id( 'sites' ); ?>"><?php _e('Sites:'); ?></label>
            
            <select name="<?php echo $this->get_field_name( 'sites' ); ?>[]" multiple="multiple" id="<?php echo $this->get_field_id( 'sites' ); ?>" style="height: 100%;" class="widefat">
            	<?php 
					foreach ( $socialsites as $social ) {
					
						if ( in_array( $social, $instance['sites'] ) )
							$selected = 'selected="selected"';
						else 
							$selected = '';
							
						echo "<option $selected value='$social'>$social</option>";
						
					}
				?>
            </select>
        </p>
        
		<?php
	}
} // class Fap_social

/** 
 * Twitter widget 
 * Gets your latest tweets
 */
class Fap_twitter extends WP_Widget {

	function fap_twitter() {
		$widget_ops = array( 'classname' => 'twitter-widget', 'description' => 'Gets your latest tweets.' );

		$this->WP_Widget( 'fap-twitter-widget',  __('Fap: Twitter', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	 
		extract( $args );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$username = $instance['username'];
		$number = $instance['number'];
		
		echo $before_widget;
		
		if ( $title )
			echo $before_title . $title . $after_title;

		// Show the photos if there's an ID
		if ( $username ) {

		?>

		<ul id="twitter_update_list">
        	<li><?php _e('Twitter feed loading...', 'fap'); ?></li>
        </ul>       

		<script type="text/javascript" src="http://twitter.com/javascripts/blogger.js"></script>
        <script type="text/javascript" src="http://twitter.com/statuses/user_timeline/<?php echo $username; ?>.json?callback=twitterCallback2&amp;count=<?php echo $number; ?>"></script>
            
	   <?php	
		} else {
			echo '<em>' . __('No Twitter username entered', 'fap') . '</em>';
		}
		
	   echo $after_widget;
   }

	// Update the widget settings
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		// Encode HTML for title, id, type and sorting
		$instance['title'] 	  = esc_html( $new_instance['title'] );
		$instance['username'] = esc_attr( $new_instance['username'] );
		$instance['number']   = intval( $new_instance['number'] );
		
		return $instance;
	}
	
   function form( $instance ) { 
   
   		$title 	  = $instance['title'];      
		$username = $instance['username'];
		$number   = $instance['number'];
		
		$defaults = array( 'title' => 'Twitter', 'username' => '', 'number' => '3' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
        
        <p>
            <label for="<?php echo $this->get_field_id('username'); ?>">
				<?php echo __('Twitter username', 'fap'); ?>
            </label>
         
            <input type="text" name="<?php echo $this->get_field_name('username'); ?>" value="<?php echo $username; ?>" class="widefat" id="<?php echo $this->get_field_id('username'); ?>" />
        </p>
        
       	<p>
            <label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php echo __('Number:', 'fap'); ?></label>
            <select name="<?php echo $this->get_field_name( 'number' ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>">
                <?php for ( $i = 1; $i <= 15; $i += 1) { ?>
                <option value="<?php echo $i; ?>" <?php if ( $instance['number'] == $i ) echo "selected='selected'"; ?>><?php echo $i; ?></option>
                <?php } ?>
            </select>
        </p>
        
		<?php
	}
} // class Fap_twitter

/*
 * Popular posts widget 
 * 
 * Gets popular posts bases on comment count
 */
class Fap_popular extends WP_Widget {

	function fap_popular() {
		$widget_ops = array( 'classname' => 'popular-posts', 'description' => 'The most popular posts based on comment count.' );

		$this->WP_Widget( 'fap-popular-posts',  __('Fap: Popular Posts', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	 
		extract( $args );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$number = $instance['number'];
		//$thumbnail = isset( $instance['show_thumbnail'] ) ? $instance['show_thumbnail'] : false;
		
		echo $before_widget;
		
		if ( $title )
			echo $before_title . $title . $after_title;
		
		$popular = new WP_Query( array( 'posts_per_page' => $number, 'orderby' => 'comment_count' ) ); 	
		
		if ( $popular->have_posts() ) :
		
			echo '<ul>';

		while ( $popular->have_posts() ) : $popular->the_post(); ?>
		
			<li>
            	<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
                    <?php 
/*						if ( $thumbnail && has_post_thumbnail() )
							the_post_thumbnail( array( 80, 80 ) );*/
							
						echo '<span>' . get_the_title() . '</span>';
					?>
                </a>
            </li>
		
		<?php endwhile;
		
			echo '</ul>';
			
		endif;

	   echo $after_widget;
   }

	// Update the widget settings
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		// Encode HTML for title, id, type and sorting
		$instance['title'] = esc_html( $new_instance['title'] );

		// Numbers has to be a number
		$instance['number'] = intval( $new_instance['number'] );
		
		//$instance['show_thumbnail'] = $new_instance['show_thumbnail'];
		
		return $instance;
	}
	
   function form( $instance ) { 
   
   		$title 	 = $instance['title'];      
		$number  = $instance['number'];
		//$show_thumbnail = $instance['show_thumbnail'];
		
		$defaults = array( 'title' => __('Popular Posts', 'fap'), 'number' => '5', 'show_thumbnail' => false );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
        
        
       	<p>
            <label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php echo __('Number:', 'fap'); ?></label>
            <select name="<?php echo $this->get_field_name( 'number' ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>">
                <?php for ( $i = 1; $i <= 15; $i += 1) { ?>
                <option value="<?php echo $i; ?>" <?php if ( $instance['number'] == $i ) echo "selected='selected'"; ?>><?php echo $i; ?></option>
                <?php } ?>
            </select>
        </p>
        
<!--		<p>
			<input class="checkbox" type="checkbox" <?php if ( $instance['show_thumbnail'] == true ) echo 'checked="checked'; ?> id="<?php echo $this->get_field_id( 'show_thumbnail' ); ?>" name="<?php echo $this->get_field_name( 'show_thumbnail' ); ?>" />
            <label for="<?php echo $this->get_field_id( 'show_thumbnail' ); ?>"><?php _e('Show Thumbnail?', 'fap'); ?></label>
        </p>-->
        
		<?php
	}
} // class Fap_popular


/*
 * List authors widget 
 * 
 * Lists all authors on the blog
 */
class Fap_authors extends WP_Widget {

	function fap_authors() {
		$widget_ops = array( 'classname' => 'authors-widget', 'description' => 'List authors on the blog' );

		$this->WP_Widget( 'fap-authors-widget',  __('Fap: List Authors', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	
		extract( $args );
		
		/* Our variables from the widget settings. */
		$title 			= apply_filters('widget_title', $instance['title'] );
		$optioncount 	= isset( $instance['optioncount'] )   ? $instance['optioncount']   : false;
		$exclude_admin 	= isset( $instance['exclude_admin'] ) ? $instance['exclude_admin'] : false;
		$show_fullname 	= isset( $instance['show_fullname'] ) ? $instance['show_fullname'] : false;
		$hide_empty 	= isset( $instance['hide_empty'] )    ? $instance['hide_empty']    : false;
		
		echo $before_widget;
		
		if ( $title )
			echo $before_title . $title . $after_title;
		
		$args = array(
			'optioncount'   => $optioncount, 
			'exclude_admin' => $exclude_admin, 
			'show_fullname' => $show_fullname,
			'hide_empty'    => $hide_empty
		);
		
		echo '<ul>';
			wp_list_authors( $args );
		echo '</ul>';
		
		echo $after_widget;
	
	}

	// Update the widget settings
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		// Encode HTML for title, id, type and sorting
		$instance['title'] 	 		= esc_html( $new_instance['title'] );
		$instance['optioncount'] 	= $new_instance['optioncount'];
		$instance['exclude_admin'] 	= $new_instance['exclude_admin'];
		$instance['show_fullname'] 	= $new_instance['show_fullname'];
		$instance['hide_empty'] 	= $new_instance['hide_empty'];
		
		return $instance;
	}
	
   function form( $instance ) { 
   
   		$title 	 	     = $instance['title'];      
		$optioncount 	 = $instance['optioncount'];
		$exclude_admin   = $instance['exclude_admin'];
		$show_fullname 	 = $instance['show_fullname'];
		$hide_empty      = $instance['hide_empty'];
		
		$defaults = array( 'title' => __('Authors', 'fap'), 'optioncount' => false, 'exclude_admin' => false, 'show_fullname' => false, 'hide_empty' => true );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php if ( $instance['optioncount'] == true ) echo 'checked="checked'; ?> id="<?php echo $this->get_field_id( 'optioncount' ); ?>" name="<?php echo $this->get_field_name( 'optioncount' ); ?>" />
            <label for="<?php echo $this->get_field_id( 'optioncount' ); ?>"><?php _e('Display the number of posts?','fap'); ?></label>
        </p>
        
		<p>
			<input class="checkbox" type="checkbox" <?php if ( $instance['exclude_admin'] == true ) echo 'checked="checked'; ?> id="<?php echo $this->get_field_id( 'exclude_admin' ); ?>" name="<?php echo $this->get_field_name( 'exclude_admin' ); ?>" />
            <label for="<?php echo $this->get_field_id( 'exclude_admin' ); ?>"><?php _e('Exclude admin?','fap'); ?></label>
        </p>
        
		<p>
			<input class="checkbox" type="checkbox" <?php if ( $instance['show_fullname'] == true ) echo 'checked="checked'; ?> id="<?php echo $this->get_field_id( 'show_fullname' ); ?>" name="<?php echo $this->get_field_name( 'show_fullname' ); ?>" />
            <label for="<?php echo $this->get_field_id( 'show_fullname' ); ?>"><?php _e('Display the authors full name', 'fap'); ?></label>
        </p>
        
		<p>
			<input class="checkbox" type="checkbox" <?php if ( $instance['hide_empty'] == true ) echo 'checked="checked'; ?> id="<?php echo $this->get_field_id( 'show_thumbnail' ); ?>" name="<?php echo $this->get_field_name( 'hide_empty' ); ?>" />
            <label for="<?php echo $this->get_field_id( 'hide_empty' ); ?>"><?php _e('Exclude users with no posts','fap'); ?></label>
        </p>
        
		<?php
	}
} // class Fap_authors

/*
 * Flickr widget 
 * 
 * Gets the latest or random photos from a Flickr user/group
 */
class Fap_flickr extends WP_Widget {

	function fap_flickr() {
		$widget_ops = array( 'classname' => 'flickr-widget', 'description' => 'This Flickr widget get photos from a Flickr ID.' );

		$this->WP_Widget( 'fap-flickr-widget',  __('Fap: Flickr', 'fap'), $widget_ops );      
	}

	function widget( $args, $instance ) { 
	 
		extract( $args );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$id = $instance['id'];
		$number = $instance['number'];
		$type = $instance['type'];
		$sorting = $instance['sorting'];
		
		echo $before_widget;
		
		if ( $title )
			echo $before_title . $title . $after_title;

		// Show the photos if there's an ID
		if ( $id ) {
	?>

		<script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=<?php echo $number; ?>&amp;display=<?php echo $sorting; ?>&amp;size=s&amp;layout=x&amp;source=<?php echo $type; ?>&amp;<?php echo $type; ?>=<?php echo $id; ?>"></script>        

	   <?php	
		} else {
			echo '<em>' . __('No Flickr ID entered', 'fap') . '</em>';
		}
		
	   echo $after_widget;
   }

	// Update the widget settings
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		// Encode HTML for title, id, type and sorting
		$instance['title'] 	 = esc_html( $new_instance['title'] );
		$instance['id'] 	 = esc_attr( $new_instance['id'] );
		$instance['type'] 	 = esc_attr( $new_instance['type'] );
		$instance['sorting'] = esc_attr( $new_instance['sorting'] );

		// Numbers has to be a number
		$instance['number'] = intval( $new_instance['number'] );
		
		return $instance;
	}
	
   function form( $instance ) { 
   
   		$title 	 = $instance['title'];      
		$id 	 = $instance['id'];
		$number  = $instance['number'];
		$type 	 = $instance['type'];
		$sorting = $instance['sorting'];
		
		$defaults = array( 'title' => 'Flickr', 'number' => '1', 'type' => 'user', 'sorting' => 'latest' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
        
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
        
        <p>
            <label for="<?php echo $this->get_field_id('id'); ?>">
				<?php echo __('Flickr ID', 'fap') . ' (<a href="http://www.idgettr.com">idGettr</a>):'; ?>
            </label>
         
            <input type="text" name="<?php echo $this->get_field_name('id'); ?>" value="<?php echo $id; ?>" class="widefat" id="<?php echo $this->get_field_id('id'); ?>" />
        </p>
        
       	<p>
            <label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php echo __('Number:', 'fap'); ?></label>
            <select name="<?php echo $this->get_field_name( 'number' ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>">
                <?php for ( $i = 1; $i < 10; $i += 1) { ?>
                <option value="<?php echo $i; ?>" <?php if ( $instance['number'] == $i ) echo "selected='selected'"; ?>><?php echo $i; ?></option>
                <?php } ?>
            </select>
        </p>
        
        <p>
            <label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e('Type:','fap'); ?></label>
            <select name="<?php echo $this->get_field_name( 'type' ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'type' ); ?>">
                <option value="user" <?php if ( $instance['type'] == "user" ) echo "selected='selected'"; ?>><?php _e('User', 'fap'); ?></option>
                <option value="group" <?php if ( $instance['type'] == "group" ) echo "selected='selected'"; ?>><?php _e('Group', 'fap'); ?></option>
            </select>
        </p>
        
        <p>
            <label for="<?php echo $this->get_field_id( 'sorting '); ?>"><?php _e('Sorting:','woothemes'); ?></label>
            <select name="<?php echo $this->get_field_name( 'sorting' ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'sorting' ); ?>">
                <option value="latest" <?php if ( $instance['sorting'] == "latest") echo "selected='selected'"; ?>><?php _e('Latest'); ?></option>
                <option value="random" <?php if ( $instance['sorting'] == "random") echo "selected='selected'"; ?>><?php _e('Random'); ?></option>            
            </select>
        </p>
        
		<?php
	}
} // class Fap_flickr 

?>